@@ -64,6 +64,8 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
         token::approve(cpi_context, token_manager.amount)?;
         
         let mint_manager_info = next_account_info(remaining_accs)?;
+        let mut mint_manager = Account::<MintManager>::try_from(mint_manager_info)?;
+        mint_manager.token_managers += 1;
         let mint = ctx.accounts.mint.key();
         let path = &[MINT_MANAGER_SEED.as_bytes(), mint.as_ref()];
         let bump_seed = assert_derivation(ctx.program_id, mint_manager_info, path)?;
